% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/dotCall64.R
\name{dotCall64}
\alias{.C64}
\alias{dotCall64}
\title{dotCall64 - Extended Foreign Function Interface}
\usage{
.C64(name, SIGNATURE, ..., INTENT = NULL, PACKAGE = "")
}
\arguments{
\item{name}{a character string giving the name of a C function or Fortran subroutine.}

\item{SIGNATURE}{a vector of type character.
It describes the signature of the C/Fortran function.
It accepts \code{"double"}, \code{"integer"}, \code{"int64"}.}

\item{...}{arguments to be passed to the foreign function. Up to 65.}

\item{INTENT}{a vector of type character. For each argument, the string indicates the intent of the function.
The accepted values are \code{"r"}, \code{"w"} or \code{"rw"} for indicating read, write respectively read/write.
If this argument is missing, it is assumed that all arguments are \code{"rw"}.
See details.}

\item{PACKAGE}{if supplied, confine the search for a character string .NAME to the DLL given by this argument (plus the conventional extension, '.so', '.dll', ...).
This is intended to add safety for packages, which can ensure by using this argument that no other package can override their external symbols, and also speeds up the search (see 'Note').}
}
\value{
A list similar to the \code{...} list of arguments passed in (including any names given to the arguments), but reflecting any changes made by the C or Fortran code.
}
\description{
\code{.C64} is a function to make calls to compiled code that has been loaded into R.
The function works similar to the ones of the Foreign Function Interface but it
\enumerate{
   \item supports long vectors.
   \item supports int64_t as argument for compiled code.
   \item duplicates objects if necessary to not corrupt another variable.
   \item casts objects to the expected argument.
}
This is achieved by the two addional arguments \code{INTENT} and \code{SIGNATURE}.
They describe how the arguments will be used.
dotCall64 will uses this information to prepare the arguments.
The user just has to describe its intentions and the package will do the actual work.
}
\details{
DotCall64 prioritizes memory efficiency over speed.
If we have an argument of signature \code{int64_t} and intent \code{"r"},
then before calling the function, \code{dotCall64} casts the double array in place
(meaning it overwrites the memory of the double object) into \code{int64_t} and casts them back after the call, such that the original object is still readable.
}
\section{Warning}{

If intent is set to \code{"w"}, then the function \emph{must not} assume that the elements are initialized to zero.
If this should be the case, use \code{"rw"} and pass a zero initialized vector.
If intent is set to \code{"r"}, then the function \emph{must not} modify the corresponding argument.
Because the corresponding argument is not copied and hence may have side effects on other R objects.
}
\examples{
\dontrun{
TODO: Demo aus Paper nehmen
}
}

